{% load i18n %}

<ul class="nav nav-tabs">
    <li class="active"><a data-toggle="tab" href="#graphs">{% translate "Graphs" %}</a></li>
    <li><a data-toggle="tab" href="#members">{% translate "Corporations" %}</a></li>
</ul>
