{% extends 'afat/base.html' %}

{% load static %}
{% load i18n %}

{% block page_title %}{% translate 'Fleet Activity' %}{% endblock %}

{% block afat_header %}
    <br>
    {% include "afat/partials/menu.html" %}

    <h2>{% translate "Create a FAT Link" %}</h2>
{% endblock %}

{% block afat_body %}
    <div class="row">
        {% include "afat/partials/fatlinks/add/esi_link.html" %}
        {% include "afat/partials/fatlinks/add/clickable_link.html" %}
    </div>
{% endblock %}

{% block extra_css %}
    <link rel="stylesheet" type="text/css" href="{% static 'afat/css/aa-bootstrap-fix.min.css' %}">
    <link rel="stylesheet" type="text/css" href="{% static 'afat/css/allianceauth-afat.min.css' %}">
{% endblock %}

{% block extra_javascript %}
    <script type="application/javascript" src="{% static 'afat/javascript/allianceauth-afat.min.js' %}"></script>
    <script type="application/javascript">
        $(document).ready(function () {
            let cancelEsiFleetModal = $('#cancelEsiFleetModal');
            manageModal(cancelEsiFleetModal);
        });
    </script>
{% endblock %}
