# Generated by Django 3.2.9 on 2021-11-09 22:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("afat", "0020_auto_20210617_1037"),
    ]

    operations = [
        migrations.AlterField(
            model_name="afatlink",
            name="fleet",
            field=models.CharField(
                default=None, help_text="The FAT link fleet name", max_length=254
            ),
        ),
    ]
