/* attempting to fix AA's wrong usage of bootstrap classes
--------------------------------------------------------------------------------------*/
@media all {
    .allianceauth-afat {
        margin-left: 15px;
    }
}

@media all and (min-width: 768px) {
    .allianceauth-afat {
        margin-left: 0;
    }
}
