{% load i18n %}

<p class="fatlink-list-legend">
    <b>{% translate "Legend" %}:</b><br>
    <span class="label label-success afat-label afat-label-via-esi afat-label-active-esi-fleet">{% translate "via ESI" %}</span> » {% translate 'Fleet is currently active and FATs are automatically being tracked via ESI' %}<br>
    <span class="label label-success afat-label afat-label-via-esi">{% translate "via ESI" %}</span> » {% translate 'FATs have been automatically tracked via ESI' %}
</p>
