{% load i18n %}

<ul class="nav nav-tabs">
    <li class="active"><a data-toggle="tab" href="#fats">{% translate "FATs" %}</a></li>
    <li><a data-toggle="tab" href="#fatlinks">{% translate "FAT Links" %}</a></li>
</ul>
