@media all {
    .btn-afat-action {
        margin: 0 0.25rem;
        height: 35px;
        width: 35px;
    }

    .fatlink-list-legend {
        border-top: 1px solid rgb(236, 240, 241);
        margin-top: 1rem;
        padding-top: 1rem;
    }

    .template-dark-mode .fatlink-list-legend {
        border-top: 1px solid rgb(70, 69, 69);
    }
}

/* esi fleet list (add fatlink view)
------------------------------------------------------------------------------------- */
@media all {
    .allianceauth-afat .esi-fleet-list {
        margin-bottom: 1rem;
        margin-top: 1rem;
        padding: 0;
    }

    .allianceauth-afat .esi-fleet-list-item {
        align-content: space-between;
        align-items: center;
        display: flex;
        flex-direction: row;
        flex-wrap: nowrap;
        justify-content: space-between;
        list-style: none;
        padding: 0.5rem 1rem;
    }

    .allianceauth-afat .esi-fleet-list-item:hover {
        background-color: rgba(0, 0, 0, 0.1);
    }

    .allianceauth-afat .esi-fleet-list-item .eve-image-with-text {
        display: flex;
    }

    .allianceauth-afat .esi-fleet-list-item .eve-image-with-text .eve-image {
        margin: auto;
    }

    .allianceauth-afat .esi-fleet-list-item .eve-character-portrait {
        margin-right: 0.5rem;
    }
}

/* tables
------------------------------------------------------------------------------------- */
@media all {
    .allianceauth-afat .table > tbody > tr > td,
    .allianceauth-afat .table > tbody > tr > th,
    .allianceauth-afat .table > tfoot > tr > td,
    .allianceauth-afat .table > tfoot > tr > th,
    .allianceauth-afat .table > thead > tr > td {
        vertical-align: middle;
    }
}

/* labels
------------------------------------------------------------------------------------- */
@media all {
    .afat-label-via-esi {
        background-color: rgb(192, 192, 192);
        color: rgb(54, 54, 54);
        margin-left: 1rem;
    }

    .afat-label-active-esi-fleet {
        background-color: rgb(98, 196, 98);
    }

    .afat-label-statistics {
        margin-left: 1rem;
        margin-right: 1rem;
        position: relative;
        top: 0.2rem;
    }
}

/* Time period select
------------------------------------------------------------------------------------- */
@media all {
    .afat-select-time-period {
        font-size: 19px;
        font-weight: 400;
        line-height: 1.1;
        margin-top: 10.5px;
        margin-bottom: 10.5px;
    }
}

/* DataTables
------------------------------------------------------------------------------------- */
@media all {
    .dataTables_wrapper > .form-inline {
        margin-bottom: 1rem;
    }

    .dataTables_wrapper > .form-inline select {
        margin-bottom: 1rem;
        margin-right: 1rem;
    }

    .dataTables_wrapper > .form-inline select:last-child {
        margin-right: 0;
    }

    .dataTables_length select {
        margin: 0 1rem;
    }
}

@media (min-width: 768px) {
    .dataTables_wrapper > .form-inline select:first-child {
        margin-left: 1rem;
    }
}
