{% load i18n %}

<div class="afat-select-time-period afat-select-year">
    <a class="btn btn-primary btn-sm" href="{{ url_previous_year }}" title='{% translate "Previous Year" %}'><i class="fas fa-backward"></i></a>

    <span class="afat-label-statistics">{{ year }}</span>

    {% if year_next <= year_current %}
        <a class="btn btn-primary btn-sm" href="{{ url_next_year }}" title='{% translate "Next Year" %}'><i class="fas fa-forward"></i></a>
        <a class="btn btn-primary btn-sm" href="{{ url_current_year }}" title='{% translate "Current Year" %}'><i class="fas fa-fast-forward"></i></a>
    {% endif %}
</div>
