{% load i18n %}

<ul class="nav nav-tabs">
    <li class="active"><a data-toggle="tab" href="#mine">{% translate "My Stats" %}</a></li>

    {% if perms.afat.stats_corporation_own or perms.afat.stats_corporation_other %}
        <li><a data-toggle="tab" href="#corps">{% translate "Corps" %}</a></li>
    {% endif %}
</ul>
