{% extends 'afat/base.html' %}

{% load static %}
{% load i18n %}
{% load evelinks %}
{% load filters %}

{% block page_title %}{% translate 'Fleet Activity' %}{% endblock %}

{% block afat_header %}
    <br>
    {% include "afat/partials/menu.html" %}

    <h2>{% translate "Statistics" %}</h2>
{% endblock %}

{% block afat_body %}
    {% url 'afat:statistics_overview' year_prev as url_previous_year %}
    {% url 'afat:statistics_overview' year_next as url_next_year %}
    {% url 'afat:statistics_overview' year_current as url_current_year %}
    {% include "afat/partials/year_navigation.html" with url_previous_year=url_previous_year url_next_year=url_next_year url_current_year=url_current_year %}

    {% include "afat/partials/statistics/overview/tabs_navigation.html" %}

    <div class="tab-content">
        {% include "afat/partials/statistics/overview/tabs/mine.html" %}

        {% if perms.afat.stats_corporation_own or perms.afat.stats_corporation_other %}
            {% include "afat/partials/statistics/overview/tabs/corps.html" %}
        {% endif %}
    </div>
{% endblock %}

{% block extra_css %}
    <link rel="stylesheet" type="text/css" href="{% static 'afat/css/aa-bootstrap-fix.min.css' %}">
    <link rel="stylesheet" type="text/css" href="{% static 'afat/css/allianceauth-afat.min.css' %}">
{% endblock %}
